## ---- results='hide', echo=FALSE, message=FALSE-----------------------------------------------------------------------
library(crunch)
load("vignettes.RData")
options(width=120)

## ---- eval=FALSE------------------------------------------------------------------------------------------------------
#  ordering(ds)

## ---- echo=FALSE------------------------------------------------------------------------------------------------------
cat(step0.print, sep="\n")

## ---- eval=FALSE------------------------------------------------------------------------------------------------------
#  ordering(ds) <- VariableOrder(
#          VariableGroup("Demos", ds[c(1, 21:37)]),
#          VariableGroup("Tracking questions", ds[c(2,3, 11:20)]),
#          VariableGroup("This week", ds[4:11])
#      )

## ---- eval=FALSE------------------------------------------------------------------------------------------------------
#  ordering(ds)

## ---- echo=FALSE------------------------------------------------------------------------------------------------------
cat(step1.print, sep="\n")

## ---- eval=FALSE------------------------------------------------------------------------------------------------------
#  names(ordering(ds))

## ---- echo=FALSE------------------------------------------------------------------------------------------------------
names(step1)

## ---- eval=FALSE------------------------------------------------------------------------------------------------------
#  names(ordering(ds))[1] <- "Demographics"
#  names(ordering(ds))

## ---- echo=FALSE------------------------------------------------------------------------------------------------------
names(step2)

## ---- eval=FALSE------------------------------------------------------------------------------------------------------
#  ordering(ds) <- ordering(ds)[c(2, 3, 1)]
#  names(ordering(ds))

## ---- echo=FALSE------------------------------------------------------------------------------------------------------
names(step3)

## ---- eval=FALSE------------------------------------------------------------------------------------------------------
#  ordering(ds)[["This week"]][["Snowden"]] <- ordering(ds)[["This week"]][1:4]
#  ordering(ds)

## ---- echo=FALSE------------------------------------------------------------------------------------------------------
cat(step4.print, sep="\n")

